pub struct UnsafeRoot {
pub def_id: DefId,
pub kinds: Vec<UnsafeOpKind>,
pub unsafe_callees: HashSet<DefId>,
pub raw_ptr_locals: HashSet<Local>,
pub static_muts: HashSet<DefId>,
}Expand description
A function that contains unsafe operations — an “unsafe root”.
This is the unified entry point for both the safetyflow analysis and the verify module to determine whether a function needs safety verification.
Fields
def_id: DefIdkinds: Vec<UnsafeOpKind>unsafe_callees: HashSet<DefId>raw_ptr_locals: HashSet<Local>static_muts: HashSet<DefId>Trait Implementations
Sourceimpl Clone for UnsafeRoot
impl Clone for UnsafeRoot
Sourcefn clone(&self) -> UnsafeRoot
fn clone(&self) -> UnsafeRoot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for UnsafeRoot
impl RefUnwindSafe for UnsafeRoot
impl Send for UnsafeRoot
impl Sync for UnsafeRoot
impl Unpin for UnsafeRoot
impl UnwindSafe for UnsafeRoot